@@ -105,7 +105,7 @@ def parse_header_block_sample_block_label_alpha_name(
         return header_block, key[0], key[1], key[2]
 
 
-# @typechecked
+# @typechecked -- typeguard does not support numpy array
 def assemble_block(n_rows: Int, n_cols: Int, pdf: pd.DataFrame, cov_matrix: NDArray[(Any, Any),
                                                                                     Float],
                    row_mask: NDArray[Any]) -> NDArray[Float]:
@@ -149,7 +149,7 @@ def assemble_block(n_rows: Int, n_cols: Int, pdf: pd.DataFrame, cov_matrix: NDAr
         return X[row_mask, :]
 
 
-@typechecked
+# @typechecked -- typeguard does not support numpy array
 def constrained_logistic_fit(X: NDArray[Float], y: NDArray[Float], alpha_arr: NDArray[Float],
                              guess: NDArray[Float], n_cov: Int) -> scipy.optimize.OptimizeResult:
     """
@@ -190,7 +190,7 @@ def constrained_logistic_fit(X: NDArray[Float], y: NDArray[Float], alpha_arr: ND
     return scipy.optimize.minimize(objective, guess, jac=gradient, method='L-BFGS-B')
 
 
-@typechecked
+# @typechecked -- typeguard does not support numpy array
 def get_irls_pieces(X: NDArray[Float], y: NDArray[Float], alpha_value: Float,
                     beta_cov: NDArray[Float]) -> (NDArray[Float], NDArray[Float], NDArray[Float]):
     """
@@ -234,7 +234,7 @@ def get_irls_pieces(X: NDArray[Float], y: NDArray[Float], alpha_value: Float,
     return beta, XtGX, XtY
 
 
-# @typechecked
+# @typechecked -- typeguard does not support numpy array
 def slice_label_rows(labeldf: pd.DataFrame, label: str, sample_list: List[str],
                      row_mask: NDArray[Any]) -> NDArray[Any]:
     """
@@ -377,7 +377,7 @@ def new_headers(header_block: str, alpha_names: Iterable[str],
     return new_header_block, sort_keys, headers
 
 
-@typechecked
+# @typechecked -- typeguard does not support numpy array
 def r_squared(XB: NDArray[Float], Y: NDArray[Float]) -> NDArray[(Any, ), Float]:
     """
     Computes the coefficient of determination (R2) metric between the matrix resulting from X*B and the matrix of labels
@@ -396,7 +396,7 @@ def r_squared(XB: NDArray[Float], Y: NDArray[Float]) -> NDArray[(Any, ), Float]:
     return 1 - (res / tot)
 
 
-@typechecked
+# @typechecked -- typeguard does not support numpy array
 def sigmoid(z: NDArray[Float]) -> NDArray[Float]:
     """
     Computes the sigmoid function for each element in input z
@@ -410,7 +410,7 @@ def sigmoid(z: NDArray[Float]) -> NDArray[Float]:
     return 1 / (1 + np.exp(-z))
 
 
-@typechecked
+# @typechecked -- typeguard does not support numpy array
 def log_loss(p: NDArray[Float], y: NDArray[Float]) -> NDArray[Float]:
     """
     Computes the log loss of probability values p and observed binary variable y.
@@ -427,7 +427,7 @@ def log_loss(p: NDArray[Float], y: NDArray[Float]) -> NDArray[Float]:
 
 
 @typechecked
-def create_alpha_dict(alphas: NDArray[(Any, ), Float]) -> Dict[str, Float]:
+def create_alpha_dict(alphas: List[float]) -> Dict[str, Float]:
     """
     Creates a mapping to attach string identifiers to alpha values.
 
@@ -437,7 +437,7 @@ def create_alpha_dict(alphas: NDArray[(Any, ), Float]) -> Dict[str, Float]:
     Returns:
         Dict of [alpha names, alpha values]
     """
-    if not (alphas >= 0).all():
+    if not all(x >= 0 for x in alphas):
         raise Exception('Alpha values must all be non-negative.')
     return {f'alpha_{i}': a for i, a in enumerate(alphas)}
 
@@ -457,7 +457,7 @@ def generate_alphas(blockdf: DataFrame) -> Dict[str, Float]:
     num_label_free_headers = blockdf.select(f.regexp_extract('header', r"^(.+?)($|_label_.*)",
                                                              1)).distinct().count()
     heritability_vals = [0.99, 0.75, 0.50, 0.25, 0.01]
-    alphas = np.array([num_label_free_headers / h for h in heritability_vals])
+    alphas = [num_label_free_headers / h for h in heritability_vals]
     print(f"Generated alphas: {alphas}")
     return create_alpha_dict(alphas)
 
